@@ -8,3 +8,11 @@ class MultipleFieldsReturned(RoboxError):
 
 class InvalidValue(RoboxError):
     ...
+
+
+class ForbiddenByRobots(RoboxError):
+    ...
+
+
+class RetryError(RoboxError):
+    ...
